@@ -3,8 +3,8 @@ from docker_registry.core import driver
 from docker_registry.core import exceptions
 from docker_registry.core import lru
 
-import fds
-
+#import fds
+import fds.GalaxyFDSClient
 class Storage(driver.Base):
 
     supports_bytes_range = False
@@ -15,7 +15,8 @@ class Storage(driver.Base):
       self.bucket = config.fds_bucket
       self.accesskey = config.fds_accesskey
       self.secretkey = config.fds_secretkey
-      self.client = fds.GalaxyFDSClient(self.accesskey, self.secretkey)
+      self.client =  fds.GalaxyFDSClient.GalaxyFDSClient(self.accesskey, self.secretkey)
+      #self.client = fds.GalaxyFDSClient(self.accesskey, self.secretkey)
 
     # Remove the first and last "/" of path for FDS
     def _init_path(self, path=None):
@@ -32,7 +33,7 @@ class Storage(driver.Base):
     def get_content(self, path):
         try:
             path = self._init_path(path)
-            return self.client.getObject(self.bucket, path)
+            return self.client.get_object(self.bucket, path)
         except:
             raise exceptions.FileNotFoundError("File not found %s" % path)
 
@@ -41,7 +42,7 @@ class Storage(driver.Base):
         #self.buffer_size = 128 * 1024
         path = self._init_path(path)
         try:
-            for i in self.client.streamGetObject(self.bucket, path, self.buffer_size):
+            for i in self.client.stream_get_object(self.bucket, path, self.buffer_size):
                 yield i
         except:
             raise exceptions.FileNotFoundError("File not found %s" % path)
@@ -51,7 +52,7 @@ class Storage(driver.Base):
     def put_content(self, path, content):
         try:
             path = self._init_path(path)
-            self.client.putObject(self.bucket, path, content)
+            self.client.put_object(self.bucket, path, content)
         except:
           raise IOError("Could not put content: %s" % path)
         return path
@@ -68,13 +69,13 @@ class Storage(driver.Base):
     # Stream put object in FDS
     def stream_write(self, path, fp):
         path = self._init_path(path)
-        self.client.streamPutObject(self.bucket, path, self.yield_content(fp))
+        self.client.stream_put_object(self.bucket, path, self.yield_content(fp))
 
     # Check if the object exists in FDS
     def exists(self, path):
         path = self._init_path(path)
         try:
-            return self.client.doesObjectExists(self.bucket, path)
+            return self.client.does_object_exists(self.bucket, path)
         except Exception:
             raise IOError("Could not check object existence: %s" % path)
             return False
@@ -84,7 +85,7 @@ class Storage(driver.Base):
     def remove(self, path):
         path = self._init_path(path)
         try:
-            self.client.deleteObject(self.bucket, path)
+            self.client.delete_object(self.bucket, path)
             return
         except Exception:
             raise exceptions.FileNotFoundError("File not found %s" % path)
@@ -93,7 +94,7 @@ class Storage(driver.Base):
     def get_size(self, path):
         path = self._init_path(path)
         try:
-            return self.client.getObjectSize(self.bucket, path)
+            return self.client.get_object_size(self.bucket, path)
         except Exception:
             raise exceptions.FileNotFoundError("File not found %s" % path)
 
@@ -105,7 +106,7 @@ class Storage(driver.Base):
             path = '%s/' % path
         exists = False
         try:
-            for d in self.client.listDirectoriesAndObjects(self.bucket, path):
+            for d in self.client.list_directories_and_objects(self.bucket, path):
                 exists = True
                 yield d
         except Exception:
